@@ -273,6 +273,6 @@ class CountryField(models.CharField):
         
 try:
     from south.modelsinspector import add_introspection_rules
-    add_introspection_rules([], ["^upy\.fields\.CountryField"])
+    add_introspection_rules([], ["^upy\.fields\.CountryField","^upy\.fields\.NullTrueField"])
 except ImportError:
     pass
\ No newline at end of file
